Welcome to SubscriptionKore's documentation!
============================================

**SubscriptionKore** is a provider-agnostic async subscription management library for SaaS applications.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   quickstart
   configuration
   usage
   api
   examples
   contributing


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`